class LazyOpt
  require 'optparse'

  def initialize(script, options={})
    @options = options
    @script = script
  end

  def add(name, short, long, description, optional=true, default=nil)
    @options[name] = {
      short: short,
      long: long,
      description: description,
      default: default,
      optional: optional,
      value: nil
    }
  end

  def [](option)
    @options[option][:value]
  end

  def parse!
    banner = "usage: #{@script} "
    @options.each do |option, config|
      if config[:optional]
        banner << "[--#{config[:long]} #{config[:long].upcase}] "
      else
        banner << "--#{config[:long]} #{config[:long].upcase} "
      end    
    end

    OptionParser.new do |opts|
      opts.banner = banner

      @options.each do |option, config|
        description = "#{config[:description]}"
        description << " (#{config[:default]})" if config[:default]
        description << " MANDATORY" unless config[:default]
        opts.on("-#{config[:short]}", "--#{config[:long]} #{config[:long].upcase}", description) do |opt|
          @options[option][:value] = opt
        end
      end
    end.parse!

    @options.each do |option, config|
      raise OptionParser::MissingArgument, "--#{option}" if (config[:value].nil? && !config[:optional])
    end

    @options.each do |option, config|
      config[:value] = config[:value] ? config[:value] : config[:default]
    end
  end 
end