#
# Author:: Kevin Moser (<kevin.moser@nordstrom.com>)
#
# Copyright:: 2012, Nordstrom, Inc.
#
# Licensed under the Apache License, Version 2.0 (the "License");
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http://www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
require 'net/smtp'

class MetricCollect
  class Backend
    class Email 
      def initialize(name)
        @params = Hash.new
        @params[:name] = name
        @params[:value] = nil
        @params[:subject] = 'Message from Metrics Collect'
        @params[:body] = nil
        @params[:to] = nil
      end

      def method_missing(method_symbol, *args, &block)
        @params[method_symbol]
      end

      attr_accessor :params

      def process_metric(config)
        name = @params[:name]
        value = @params[:value]
        subject = @params[:subject]
        body = @params[:body]
        to = @params[:to]
        @config = config.params

        send_email(name, value, to, subject, body)
      end

      private
      def send_email(name, value, to, subject, body)
        msg = <<-EOF
From: <#{@config[:email_from]}>
To: <#{to}>
Subject: #{subject}

#{body}
        EOF

        Net::SMTP.start(@config[:email_server]) do |smtp|
          smtp.send_message msg, @config[:email_from], to
        end
      end
   end
  end
end

