#
# Author:: Kevin Moser (<kevin.moser@nordstrom.com>)
#
# Copyright:: 2012, Nordstrom, Inc.
#
# Licensed under the Apache License, Version 2.0 (the "License");
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http://www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
require 'socket'

class MetricCollect
  class Backend
    class Graphite 
      def initialize(name)
        @params = Hash.new
        @params[:name] = name
        @params[:value] = nil
        @params[:key] = "metric_collect"
      end

      def method_missing(method_symbol, *args, &block)
        @params[method_symbol]
      end

      attr_accessor :params
      
      def process_metric(config)
        @config = config.params
        name = @params[:name]
        value = @params[:value]
        key = @params[:key]

        report("#{key}.#{name}", value)
      end

      private
      def socket
        host = @config[:graphite_server]
        port = @config[:graphit_port]

        return @socket if @socket && !@socket.closed?
        @socket = TCPSocket.new(@config[:graphite_server], @config[:graphite_port])
      end

      def report(key, value, time = Time.now)
        begin
          socket.write("#{key} #{value.to_f} #{time.to_i}\n")
        rescue Errno::EPIPE, Errno::EHOSTUNREACH, Errno::ECONNREFUSED
          @socket = nil
          nil
        end
      end

      def close_socket
        @socket.close if @socket
        @socket = nil
      end      
    end
  end
end

