#
# Author:: Kevin Moser (<kevin.moser@nordstrom.com>)
#
# Copyright:: 2012, Nordstrom, Inc.
#
# Licensed under the Apache License, Version 2.0 (the "License");
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http://www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
class MetricCollect
  class Log
    def initialize(log_file=nil)
      @log_file = log_file
    end

    def self.info(msg)
      Log.write(msg, "INFO")
    end

    def self.warn(msg)
      Log.write(msg, "WARN")
    end

    def self.fatal(msg, error=nil)
      Log.write(msg, "FATAL")
      raise error if error
      exit
    end

    def self.build_time
      time = Time.now
      year = "%04d" % time.year
      month = "%02d" % time.month
      day = "%02d" % time.day
      hour = "%02d" % time.hour
      min = "%02d" % time.min
      sec = "%02d" % time.sec
      
      "#{year}-#{month}-#{day} #{hour}:#{min}:#{sec}"
    end

    private
    def self.write(msg, level)
      if @log_file
        File.open(@log_file, 'w') do |log|
          log.write("#{build_time}|#{level}|#{msg}")
        end
      else
        puts "#{build_time}|#{level}|#{msg}"
      end
    end
  end
end