#
# Author:: Kevin Moser (<kevin.moser@nordstrom.com>)
#
# Copyright:: 2012, Nordstrom, Inc.
#
# Licensed under the Apache License, Version 2.0 (the "License");
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http://www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
class MetricCollect
  class Metric
    attr_reader :backends
    attr_accessor :name

    def initialize(name=nil)
      @backends = Array.new
      @name = name
    end

    def method_missing(method_symbol, *args, &block)
      case method_symbol
      when :statsd
        @new_backend = MetricCollect::Backend::Statsd.new(args[0])
      when :graphite
        @new_backend = MetricCollect::Backend::Graphite.new(args[0])
      when :email
        @new_backend = MetricCollect::Backend::Email.new(args[0])
      else
        if @new_backend.params.has_key?(method_symbol)
          @new_backend.params[method_symbol] = args[0]
        else
          raise ArgumentError.new("No argument for #{@new_backend.class} named #{method_symbol.to_s}")
        end
        return
      end

      begin
        yield if block
      rescue => error
        MetricCollect::Log.fatal("Error loading value[#{name}::#{@new_backend.name}]", error)
      end
      @backends << @new_backend
    end

    def send(config)
      @backends.each do |backend|
        MetricCollect::Log.info("Processing value[#{name}::#{backend.name}] sending key: #{backend.key} value: #{backend.value} to #{backend.class}")
        backend.process_metric(config)
      end
    end
  end
end